==> viha-5.15.tar.gz: viha-5.15/ryhma_tila.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "ryhma_tila";
$file = basename(__FILE__);

include "common.php";
include "ryhma_tila-ok.php";

echo "
<html>
<head>
 <title>VIHA - Ryhmn tilakoodit</title>
</head>
" . body_bgcolor() . "
<h1>Ryhmn tilakoodien ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$ryhma_tila = get_txt('ryhma_tila');
$suojattu = get_txt('suojattu');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_sallittu($file, $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = ryhma_tila_add_ok($herja,s('alue'),
			   s('paivystys'),
			   $ryhma_tila);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET alue_id = " . s("alue") . ",
           paivystys_id = " . s("paivystys") . ",
           ryhma_tila = '$ryhma_tila',
           suojattu = 0,
           ts = '$now'";
    $result = my_mysql_query ($sql);
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
  }
  p_herja($ret,$herja);
 }

if (($save != '') && saa_tehda("$file:save")) {
  $ret = ryhma_tila_save_ok($herja,$id,s('alue'),
			    s('paivystys'),
			    $ryhma_tila);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET alue_id = " . s("alue") . ",
           paivystys_id=" . s("paivystys") . ",
           ryhma_tila='$ryhma_tila',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    loki($sql);
  }
  p_herja($ret,$herja);
 }

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = ryhma_tila_remove_ok($herja,$id,true);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot poistettu.\n";
    $clear = "SISINEN";
    loki($sql);
  }
  p_herja($ret,$herja);
}

if ($clear != '') {
  $id = "0";
  $ryhma_tila = '';
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = ryhma_tila_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $ryhma_tila = $a['ryhma_tila'];
  $suojattu = $a['suojattu'];
  if ($suojattu == 1) { $readonly = 1; }
}		  

echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Tilakoodi:";
if ($readonly) {
  echo "<td>$ryhma_tila\n";
} else {
  echo "<td><input type=\"text\" name=\"ryhma_tila\" size=64 maxlength=64";
  echo " value=\"$ryhma_tila\">\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$result = my_mysql_query("
SELECT *
FROM $table
ORDER BY ryhma_tila
");
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  echo tr_bgcolor()
    . "<TH>Id<TH>Aikaleima<TH>Tilakoodi\n";
  while ($a = mysql_fetch_array($result)) {
    # just skip those items we do not have permission to
    if (visible_operation_tab($herja,$table,$a['id'],false) == 2)
      continue; 
    echo "<TR><TD>$a[id]", "<TD>$a[ts]", "<TD>$a[ryhma_tila]";
    if (($id == "0") && ($a['id'] != "1")) {
      if ($a['suojattu'] == 0) {
	echo "<td><a href=\"$table.php?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
	echo "<td><a href=\"$table.php?id=$a[id]&remove=POISTA\">POISTA</a>\n";
      }
    }
  }
  echo "</TABLE>";
 } else {
  echo "<P>Plop. Ei ryhmn tilakoodeja.";
 }

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: ryhma_tila.php,v 1.12 2009/04/18 16:06:56 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/ryhma_tila.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "ryhma_tila";
$file = basename(__FILE__);

include "common.php";
include "ryhma_tila-ok.php";

echo "
<html>
<head>
 <title>VIHA - Ryhmn tilakoodit</title>
</head>
" . body_bgcolor() . "
<h1>Ryhmn tilakoodien ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$ryhma_tila = get_txt('ryhma_tila');
$suojattu = get_txt('suojattu');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_sallittu($file, $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = ryhma_tila_add_ok($herja,s('alue'),
			   s('paivystys'),
			   $ryhma_tila);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET alue_id = " . s("alue") . ",
           paivystys_id = " . s("paivystys") . ",
           ryhma_tila = '$ryhma_tila',
           suojattu = 0,
           ts = '$now'";
    $result = my_mysql_query ($sql);
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
    $msg = "Listty ryhmn tilakoodi $ryhma_tila";
    taktinen_loki($msg);
    tehty($msg);
  }
  p_herja($ret,$herja);
 }

if (($save != '') && saa_tehda("$file:save")) {
  $ret = ryhma_tila_save_ok($herja,$id,s('alue'),
			    s('paivystys'),
			    $ryhma_tila);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET alue_id = " . s("alue") . ",
           paivystys_id=" . s("paivystys") . ",
           ryhma_tila='$ryhma_tila',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql,true,true);
    $msg = "Pivitetty ryhmn tilakoodia $ryhma_tila";
    taktinen_loki($msg);
    tehty($msg);
  }
  p_herja($ret,$herja);
 }

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = ryhma_tila_remove_ok($herja,$id,true);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $msg = "Poistettu ryhmn tilakoodi " . ota_ryhma_tila($id);
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql,true,true);
    $clear = "SISINEN";
    tehty($msg);
    taktinen_loki($msg);
  }
  p_herja($ret,$herja);
}

if ($clear != '') {
  $id = "0";
  $ryhma_tila = '';
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = ryhma_tila_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $ryhma_tila = $a['ryhma_tila'];
  $suojattu = $a['suojattu'];
  if ($suojattu == 1) { $readonly = 1; }
}		  

echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Tilakoodi:";
if ($readonly) {
  echo "<td>$ryhma_tila\n";
} else {
  echo "<td><input type=\"text\" name=\"ryhma_tila\" size=64 maxlength=64";
  echo " value=\"$ryhma_tila\">\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$result = my_mysql_query("
SELECT *
FROM $table
ORDER BY ryhma_tila
");
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  tr_reset();
  echo tr_vaalsin()
    . "<TH>Id<TH>Aikaleima<TH>Tilakoodi\n";
  while ($a = mysql_fetch_array($result)) {
    # just skip those items we do not have permission to
    if (visible_operation_tab($herja,$table,$a['id'],false) == 2)
      continue; 
    echo tr() . "<TD>$a[id]", "<TD>$a[ts]", "<TD>$a[ryhma_tila]";
    if (($id == "0") && ($a['id'] != "1")) {
      if ($a['suojattu'] == 0) {
	echo "<td><a href=\"$table.php?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
	echo "<td><a href=\"$table.php?id=$a[id]&remove=POISTA\">POISTA</a>\n";
      }
    }
  }
  echo "</TABLE>";
 } else {
  echo "<P>Plop. Ei ryhmn tilakoodeja.";
 }

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: ryhma_tila.php,v 1.14 2009/10/06 08:20:07 riku Exp $ -->
